summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorGrant Limberg <glimberg@gmail.com>2015-06-17 18:42:23 -0700
committerGrant Limberg <glimberg@gmail.com>2015-06-17 18:42:23 -0700
commitdfdd46db80331104366747e336323095aba2c886 (patch)
tree9d7d65a6fcee14f59b9e07dca248a9ae3e180e4e /include
parentc59c74dddab862ade65938e630dc0f561fcb0c2f (diff)
parent87bb0086deadf3663c3e0ec1308e0d71a6473362 (diff)
downloadinfinitytier-dfdd46db80331104366747e336323095aba2c886.tar.gz
infinitytier-dfdd46db80331104366747e336323095aba2c886.zip
Merge branch 'adamierymenko-dev' into android-jni
Diffstat (limited to 'include')
-rw-r--r--include/ZeroTierOne.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/ZeroTierOne.h b/include/ZeroTierOne.h
index 9b82c8d6..b67d97ed 100644
--- a/include/ZeroTierOne.h
+++ b/include/ZeroTierOne.h
@@ -251,7 +251,7 @@ enum ZT1_Event
/**
* A more recent version was observed on the network
*
* Right now this is only triggered if a hub or supernode reports a
* more recent version, and only once. It can be used to trigger a
* software update check.
*
@@ -560,7 +560,7 @@ typedef struct
enum ZT1_PeerRole {
ZT1_PEER_ROLE_LEAF = 0, // ordinary node
ZT1_PEER_ROLE_HUB = 1, // locally federated hub
- ZT1_PEER_ROLE_SUPERNODE = 2 // planetary supernode
+ ZT1_PEER_ROLE_ROOTSERVER = 2 // planetary rootserver
};
/**
@@ -251,7 +251,7 @@ enum ZT1_Event
* A more recent version was observed on the network
*
- * Right now this is only triggered if a hub or supernode reports a
+ * Right now this is only triggered if a hub or rootserver reports a
* more recent version, and only once. It can be used to trigger a
* software update check.